/*globals define*/

define([
    'testsuite/qunit',
    'jquery',
    'ep/fn/video',

    '$ready!'
], function (QUnit, $, video) {

    var youtubeObj = JSON.parse('{"id":"0SclGz7j-p4","ext":"?list=PL5DlAwWnKPrhv_pGkElTph0M-jTx8whQE","url":"https://youtu.be/0SclGz7j-p4?list=PL5DlAwWnKPrhv_pGkElTph0M-jTx8whQE","src":"https://img.youtube.com/vi/0SclGz7j-p4/hqdefault.jpg"}'),
        vimeoObj = JSON.parse('{\"name\":\"vimeo\",\"iframe\":\"<iframe class=\\\"ep-video-iframe\\\" src=\\\"https://dummyhost.de/epages/dummyshop.admin/?ViewAction=DereferredRedirect&URL=https%3A//player.vimeo.com/video/312111187%3Fapp_id%3D122963%26dnt%3D1&nonce=MzgyYjM5NjVmNTcyOTJmZjdiODM0NDQ5NWExMGMwZmFmMWMzODU5YTJmMzQ4ZDczMWQ5OWY0NGVmYTNjMjBhOF8xNTUxNjg1MTI1\\\" width=\\\"640\\\" height=\\\"360\\\" frameborder=\\\"0\\\" title=\\\"Das Design Ihres Onlineshops\\\" allow=\\\"autoplay; fullscreen\\\" allowfullscreen></iframe>\",\"id\":312111187}');

    QUnit.module("ep/fn/video");

    QUnit.test("ep/fn/video - methods", function () {
        $.each(['youtubeIframe', 'vimeoIframe'], function (i, fn) {
            QUnit.strictEqual(
                $.isFunction(video[fn]),
                true,
                '$.isFunction(' + fn + '):'
            );
        });
    });

    QUnit.test("ep/fn/video - functionality for youtubeIframe", function () {
        var videoIframe = video.youtubeIframe(youtubeObj),
            iframeElem,
            srcAttr;

        QUnit.equal(
            videoIframe.hasClass('ep-video-container'),
            true,
            'Video container has the correct class.'
        );

        iframeElem = videoIframe.find('.ep-video-iframe');
        QUnit.equal(
            iframeElem.length,
            1,
            'Wrapper contains a video iframe.'
        );

        srcAttr = iframeElem.attr('src');
        QUnit.equal(
            RegExp(youtubeObj.id).test(srcAttr),
            true,
            'Video URL contains video id "' + youtubeObj.id + '".'
        );
        QUnit.equal(
            RegExp(youtubeObj.ext.replace(/\?/g, "\\?")).test(srcAttr),
            true,
            'Video URL contains video the extension "' + youtubeObj.ext + '".'
        );
    });


    QUnit.test("ep/fn/video - functionality for vimeoIframe", function () {
        var videoIframe = video.vimeoIframe(vimeoObj),
            iframeElem,
            srcAttr;

        QUnit.equal(
            videoIframe.hasClass('ep-video-container'),
            true,
            'Video container has the correct class.'
        );

        iframeElem = videoIframe.find('.ep-video-iframe');
        QUnit.equal(
            iframeElem.length,
            1,
            'Wrapper contains a video iframe.'
        );

        srcAttr = iframeElem.attr('src');
        QUnit.equal(
            RegExp(vimeoObj.id).test(srcAttr),
            true,
            'Video URL contains video id "' + vimeoObj.id + '".'
        );
    });
});